==> ssh-generator-1.0.6.tgz: package/README.md <==
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![npm version](https://badge.fury.io/js/ssh-generator.svg)](https://badge.fury.io/js/ssh-generator)

# SSH Generator

Simple tool to generate ssh keys. Every time when i used to create ssh keys it generally took at least 10mins as a beginner. It will not take more than 2mins to create your ssh keys using this.

## Usage

With [npm](https://npmjs.org/) installed, run

```
npm install -g ssh-generator
```

### Create your ssh keys

```
ssh-generator
```

Select one of the three big git services for which you want to create your keys for. Or select custom to create keys for custom domains.


## Why ?

As mentioned above it generally took at least 10-15mins for me to create those keys and get them up and running. Post searching for the steps again and again. This shouldn't take more than a minute to create your ssh keys.

## Built With

* [Inquirer](https://github.com/SBoudrias/Inquirer.js) - Interactive CLI user interface.
* [npm](https://www.npmjs.com/) - Package manager

## Contributing

Please read [CONTRIBUTING.md](CONTRIBUTING.MD) for details on our code of conduct, and the process for submitting pull requests to us.

## Authors

* **Gururaj Dharani** - *Initial work* - [Gururaj26](https://github.com/Gururaj26)

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE) file for details

## Acknowledgments

* Hat tip to anyone whose code was used

==> ssh-generator-1.0.7.tgz: package/README.md <==
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![npm version](https://badge.fury.io/js/ssh-generator.svg)](https://badge.fury.io/js/ssh-generator)
[![Open Source Love](https://badges.frapsoft.com/os/v3/open-source.svg?v=103)](https://github.com/ellerbrock/open-source-badges/)

# SSH Generator

Simple tool to generate ssh keys. Every time when i used to create ssh keys it generally took at least 10mins as a beginner. It will not take more than 2mins to create your ssh keys using this.

Built to save 5mins of life 👌 !

> If you think so, support me with a `star` and a `follow` 😘

## Usage

With [npm](https://npmjs.org/) installed, run

```
npm install -g ssh-generator
```

### Create your ssh keys with SSH Generator

```
ssh-generator
```

Select one of the three big git services for which you want to create your keys for. Or select custom to create keys for custom domains.


## Why ?

As mentioned above it generally took at least 10-15mins for me to create those keys and get them up and running. Post searching for the steps again and again. This shouldn't take more than a minute to create your ssh keys.

## Built With

* [Inquirer](https://github.com/SBoudrias/Inquirer.js) - Interactive CLI user interface.
* [npm](https://www.npmjs.com/) - Package manager

## Contributing

Please read [CONTRIBUTING.md](CONTRIBUTING.MD) for details on our code of conduct, and the process for submitting pull requests to us.

## Authors

* **Gururaj Dharani** - *Initial work* - [Gururaj26](https://github.com/Gururaj26)

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE) file for details

## Acknowledgments

* Hat tip to anyone whose code was used
